@@ -27,10 +27,11 @@ def qq_download_by_vid(vid, title, output_dir='.', merge=True, info_only=False):
     part_urls= []
     total_size = 0
     for part in range(1, seg_cnt+1):
-        if seg_cnt == 1 and video_json['vl']['vi'][0]['vh'] <= 480:
-            filename = fn_pre + '.mp4'
-        else:
-            filename = fn_pre + '.p' + str(part_format_id % 10000) + '.' + str(part) + '.mp4'
+        #if seg_cnt == 1 and video_json['vl']['vi'][0]['vh'] <= 480:
+        #    filename = fn_pre + '.mp4'
+        #else:
+        #    filename = fn_pre + '.p' + str(part_format_id % 10000) + '.' + str(part) + '.mp4'
+        filename = fn_pre + '.p' + str(part_format_id % 10000) + '.' + str(part) + '.mp4'
         key_api = "http://vv.video.qq.com/getkey?otype=json&platform=11&format={}&vid={}&filename={}&appver=3.2.19.333".format(part_format_id, vid, filename)
         part_info = get_content(key_api)
         key_json = json.loads(match1(part_info, r'QZOutputJson=(.*)')[:-1])
@@ -138,8 +139,9 @@ def qq_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
         title = vid
     else:
         content = get_content(url)
-        vid = parse_qs(urlparse(url).query).get('vid') #for links specified vid  like http://v.qq.com/cover/p/ps6mnfqyrfo7es3.html?vid=q0181hpdvo5
-        vid = vid[0] if vid else match1(content, r'vid"*\s*:\s*"\s*([^"]+)"') #general fallback
+        #vid = parse_qs(urlparse(url).query).get('vid') #for links specified vid  like http://v.qq.com/cover/p/ps6mnfqyrfo7es3.html?vid=q0181hpdvo5
+        vid = url.split('/')[-1].split('.')[0] #https://v.qq.com/x/cover/ps6mnfqyrfo7es3/q0181hpdvo5.html?
+        vid = vid if vid else match1(content, r'vid"*\s*:\s*"\s*([^"]+)"') #general fallback
         if vid is None:
             vid = match1(content, r'id"*\s*:\s*"(.+?)"')
         title = match1(content,r'<a.*?id\s*=\s*"%s".*?title\s*=\s*"(.+?)".*?>'%vid)
