@@ -7,13 +7,14 @@ import json
 import time
 
 def quanmin_download(url, output_dir = '.', merge = True, info_only = False, **kwargs):
-    roomid = url[url.rfind("/")+1:]
-    json_request_url = 'http://www.quanmin.tv/json/rooms/{}/info4.json'.format(roomid)
+    roomid = url.split('/')[3].split('?')[0]
+
+    json_request_url = 'http://m.quanmin.tv/json/rooms/{}/noinfo6.json'.format(roomid)
     content = get_html(json_request_url)
     data = json.loads(content)
 
     title = data["title"]
-    
+
     if not data["play_status"]:
         raise ValueError("The live stream is not online!")
     real_url = "http://flv.quanmin.tv/live/{}.flv".format(roomid)
