@@ -83,7 +83,7 @@ class YouTube(VideoExtractor):
     def get_vid_from_url(url):
         """Extracts video ID from URL.
         """
-        return match1(url, r'youtu\.be/([^/]+)') or \
+        return match1(url, r'youtu\.be/([^?/]+)') or \
           match1(url, r'youtube\.com/embed/([^/?]+)') or \
           match1(url, r'youtube\.com/v/([^/?]+)') or \
           match1(url, r'youtube\.com/watch/([^/?]+)') or \
